import "Turbine";
import "Turbine.Debug";
import "Turbine.Gameplay";
import "Turbine.UI";
import "Turbine.UI.Lotro";
import "DhorPlugins.Extensions";
import "DhorPlugins.Utils.BitOps";
import "DhorPlugins.Travel.OrendarUIMods.CheckBox"

OptionsWindow = class(Turbine.UI.Lotro.Window);

function OptionsWindow:Constructor(parent)
	Turbine.UI.Lotro.Window.Constructor( self );
	
	self.width = 500;
	self.height = 580;
	self.windowWidth, self.windowHeight = Turbine.UI.Display:GetSize();
	
	self.labels = { };
	self.checks = { };
	self.mainWindow = parent;
   
   self.sortSelectedIndex = 1;
   self.sortMaxItem = 0;
   
   self.loading = true;                                                                      
	
	self:SetPosition(self.windowWidth /2 - self.width/2,self.windowHeight/2 - self.height/2);	
	self:SetSize( self.width, self.height );
	self:SetBlendMode(Turbine.UI.BlendMode.Undefined);
	self:SetBackColor( Turbine.UI.Color(0.0,0,0,0) );
	self:SetText( "Options" );
	self:SetOpacity( 1 );
	
	self.OptionTabs = DhorPlugins.Extensions.DPanel();
	self.OptionTabs:SetOpacity(1);
	self.OptionTabs:SetSize(self.width - 20,self.height - 60);
	self.OptionTabs:SetPosition(10,40);	
	self.OptionTabs:SetParent(self);
	self.OptionTabs:SetBlendMode(Turbine.UI.BlendMode.Overlay);
	self.OptionTabs:SetBackColor(Turbine.UI.Color(0.87,0,0,0));
	self.OptionTabs:SetVisible(true);
	
	self.EnabledTab = Turbine.UI.Control();
	--self.EnabledTab:SetParent(self.OptionsTabs);
	self.SortTab = Turbine.UI.Control(); 
	--self.SortTab:SetParent(self.OptionsTabs);
	
	self:AddBoxes();
	self:AddItems();
	self:AddSortList();
	self:AddSortButtons();
	
	self.OptionTabs:AddTab(self.EnabledTab);
	self.OptionTabs:AddTab(self.SortTab);
	
	self.OptionTabs:SetTabText(1,"Select"); 
	self.OptionTabs:SetTabText(2,"Sort");
	
	self.loading = false;
	
   self.VisibleChanged = function(sender,args)
      if(self:IsVisible() == false) then
         parent:CloseOptions();
      end
   end	
end


function OptionsWindow:AddItems()
   counter = 1;
   offsetCounter = 0;

   for i = 1,travelCount[3],1 do
      self:Add(counter,genLocations:KeyAtIndex(i),5,25,offsetCounter);      
      counter = counter + 1;      
      offsetCounter = offsetCounter + 1;
   end

   offsetCounter = 0;   
   for i = 1,travelCount[5],1 do
      self:Add(counter,racialLocations:KeyAtIndex(i),250,25,offsetCounter);      
      counter = counter + 1;      
      offsetCounter = offsetCounter + 1;
   end
   
   offsetCounter = 0;   
   for i = 1,travelCount[1],1 do
      self:Add(counter,hunterLocations:KeyAtIndex(i),250,150,offsetCounter);      
      counter = counter + 1;      
      offsetCounter = offsetCounter + 1;
   end
   
   offsetCounter = 0;   
   for i = 1,travelCount[2],1 do
      self:Add(counter,wardenLocations:KeyAtIndex(i),5,150,offsetCounter);      
      counter = counter + 1;      
      offsetCounter = offsetCounter + 1;
   end
   
   offsetCounter = 0;   
   for i = 1,travelCount[4],1 do
      self:Add(counter,repLocations:KeyAtIndex(i),5,350,offsetCounter);      
      counter = counter + 1;      
      offsetCounter = offsetCounter + 1;
   end
end

function OptionsWindow:Add(index,text,xOffset,yOffset,offset)
      self.labels[index] = DhorPlugins.Extensions.DLabel();
      self.labels[index]:SetSize(200,20);
      self.labels[index]:SetPosition(xOffset,yOffset + (offset) * 20);
      self.labels[index]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
      self.labels[index]:SetParent(self.EnabledTab);
      self.labels[index]:SetText(text);
      self.labels[index]:SetData(text);
      self.labels[index]:SetVisible(true);
      
      self.checks[index] = DhorPlugins.Travel.OrendarUIMods.CheckBox();
      self.checks[index]:SetSize(20,20);
      self.checks[index]:SetPosition(xOffset + 200,yOffset + (offset) * 20);
      self.checks[index]:SetChecked(settings.enabled[text]);
      self.checks[index]:SetParent(self.EnabledTab);
      self.checks[index]:SetVisible(true);
      
      
      self.checks[index].Click = function(sender,args)
         settings.enabled[text] = sender:IsChecked();
         self.mainWindow:SetShortcuts();
		   self.mainWindow:UpdateSettings();
      end
end

function OptionsWindow:AddBoxes()

   self.genLabel = DhorPlugins.Extensions.DLabel();
   self.genLabel:SetSize(200,20);
   self.genLabel:SetPosition(0,0);
   self.genLabel:SetTextAlignment(Turbine.UI.ContentAlignment.BottomLeft);
   self.genLabel:SetFont(Turbine.UI.Lotro.Font.Verdana16);
   self.genLabel:SetText("Generic Skills");
   self.genLabel:SetParent(self.EnabledTab);
   self.genLabel:SetVisible(true);   
   self.genBox = Turbine.UI.Lotro.TextBox();
   self.genBox:SetSize(230,90);
   self.genBox:SetPosition(0,20);
   self.genBox:SetZOrder(0);
   self.genBox:SetParent(self.EnabledTab);
   self.genBox:SetReadOnly(true);
   self.genBox:SetVisible(true);
   
   self.raceLabel = DhorPlugins.Extensions.DLabel();
   self.raceLabel:SetSize(200,20);
   self.raceLabel:SetPosition(245,0);
   self.raceLabel:SetTextAlignment(Turbine.UI.ContentAlignment.BottomLeft);
   self.raceLabel:SetFont(Turbine.UI.Lotro.Font.Verdana16);
   self.raceLabel:SetText("Racial Skills");
   self.raceLabel:SetParent(self.EnabledTab);
   self.raceLabel:SetVisible(true);
   self.raceBox = Turbine.UI.Lotro.TextBox();
   self.raceBox:SetSize(230,90);
   self.raceBox:SetPosition(245,20);
   self.raceBox:SetZOrder(0);
   self.raceBox:SetParent(self.EnabledTab);
   self.raceBox:SetReadOnly(true);
   self.raceBox:SetVisible(true);

   self.wardenLabel = DhorPlugins.Extensions.DLabel();
   self.wardenLabel:SetSize(200,20);
   self.wardenLabel:SetPosition(0,125);
   self.wardenLabel:SetTextAlignment(Turbine.UI.ContentAlignment.BottomLeft);
   self.wardenLabel:SetFont(Turbine.UI.Lotro.Font.Verdana16);
   self.wardenLabel:SetText("Warden Skills");
   self.wardenLabel:SetParent(self.EnabledTab);
   self.wardenLabel:SetVisible(true);    
   self.wardenBox = Turbine.UI.Lotro.TextBox();
   self.wardenBox:SetSize(230,170);
   self.wardenBox:SetPosition(0,145);
   self.wardenBox:SetZOrder(0);
   self.wardenBox:SetParent(self.EnabledTab);
   self.wardenBox:SetReadOnly(true);
   self.wardenBox:SetVisible(true);
   
   self.hunterLabel = DhorPlugins.Extensions.DLabel();
   self.hunterLabel:SetSize(200,20);
   self.hunterLabel:SetPosition(245,125);
   self.hunterLabel:SetTextAlignment(Turbine.UI.ContentAlignment.BottomLeft);
   self.hunterLabel:SetFont(Turbine.UI.Lotro.Font.Verdana16);
   self.hunterLabel:SetText("Hunter Skills");
   self.hunterLabel:SetParent(self.EnabledTab);
   self.hunterLabel:SetVisible(true)   
   self.hunterBox = Turbine.UI.Lotro.TextBox();
   self.hunterBox:SetSize(230,310);
   self.hunterBox:SetPosition(245,145);
   self.hunterBox:SetZOrder(0);
   self.hunterBox:SetParent(self.EnabledTab);
   self.hunterBox:SetReadOnly(true);
   self.hunterBox:SetVisible(true);
   
   self.repLabel = DhorPlugins.Extensions.DLabel();
   self.repLabel:SetSize(200,20);
   self.repLabel:SetPosition(0,325);
   self.repLabel:SetTextAlignment(Turbine.UI.ContentAlignment.BottomLeft);
   self.repLabel:SetFont(Turbine.UI.Lotro.Font.Verdana16);
   self.repLabel:SetText("Reputation Skills");
   self.repLabel:SetParent(self.EnabledTab);
   self.repLabel:SetVisible(true);   
   self.repBox = Turbine.UI.Lotro.TextBox();
   self.repBox:SetSize(230,150);
   self.repBox:SetPosition(0,345);
   self.repBox:SetZOrder(0);
   self.repBox:SetParent(self.EnabledTab);
   self.repBox:SetReadOnly(true);
   self.repBox:SetVisible(true);
end

function OptionsWindow:AddSortList()
   self.sortListBox = Turbine.UI.ListBox();
   self.sortListBox:SetSize(280,490);
   self.sortListBox:SetPosition(200,5);
   self.sortListBox:SetParent(self.SortTab);
   self.sortListBox:SetVisible(true);

   counter = 1;  
   for i,v in pairs(travelShortcuts) do
        tempLabel = DhorPlugins.Extensions.DLabel();
        tempLabel:SetText(v:GetName());
        tempLabel:SetSize(280,20);
        tempLabel:SetBackColor(Turbine.UI.Color(0.87,0.1,0.1,0.1));
        tempLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
        tempLabel:SetIndex(counter);
        tempLabel:SetZOrder(90);
        
        tempLabel.MouseClick = function(sender,args)        
           self.sortListBox:GetItem(self.sortSelectedIndex):SetBackColor(Turbine.UI.Color(0.87,0.1,0.1,0.1));
           sender:SetBackColor(Turbine.UI.Color(0.95,0.1,0.1,0.6));
           self.sortSelectedIndex = self.sortListBox:IndexOfItem(sender);
        end
        
        self.sortListBox:AddItem(tempLabel);
        
        self.sortMaxItem = counter;
        counter = counter + 1;
   end
   
   -- set the first item as selected
   self.sortListBox:GetItem(self.sortSelectedIndex):SetBackColor(Turbine.UI.Color(0.87,0.1,0.1,0.6));
   
   -- set up the scrollbar for the list

	--self.listBoxScrollBar = Turbine.UI.Lotro.ScrollBar();
	self.listBoxScrollBar = self.sortListBox:GetVerticalScrollBar();
	
	if(self.listBoxScrollBar == nil) then
	   self.listBoxScrollBar = Turbine.UI.Lotro.ScrollBar();
	end
	
	self.listBoxScrollBar:SetBackColor(Turbine.UI.Color(0.87,0.1,0.1,0.1));
	self.listBoxScrollBar:SetOrientation( Turbine.UI.Orientation.Vertical );	
	self.listBoxScrollBar:SetSize( 10,490 );
	self.listBoxScrollBar:SetPosition ( 270,0);
	self.listBoxScrollBar:SetZOrder(100);
	self.listBoxScrollBar:SetVisible( true );
	self.listBoxScrollBar:SetParent(self.sortListBox);

	-- set the listbox scrollbar
	self.sortListBox:SetVerticalScrollBar(self.listBoxScrollBar);  


end

function OptionsWindow:AddSortButtons()
   self.moveUpButton = Turbine.UI.Lotro.Button();
   self.moveUpButton:SetSize(185,20);
   self.moveUpButton:SetPosition(10, 205);
   self.moveUpButton:SetText("Move Up");
   self.moveUpButton:SetParent(self.SortTab);
   self.moveUpButton:SetVisible(true);
   
   self.moveDownButton = Turbine.UI.Lotro.Button();
   self.moveDownButton:SetSize(185,20);
   self.moveDownButton:SetPosition(10, 265);
   self.moveDownButton:SetText("Move Down");
   self.moveDownButton:SetParent(self.SortTab);
   self.moveDownButton:SetVisible(true);   
   
   self.moveUpButton.Click = function(sender,args)
      if(self.sortSelectedIndex == 1) then
         --Turbine.Shell.WriteLine("At the top");
         return;
      end
   
      self:SwapShortcuts(self.sortSelectedIndex, self.sortSelectedIndex - 1);      
      
      self.mainWindow:SetShortcuts();
		self.mainWindow:UpdateSettings();
      
      self.sortSelectedIndex = self.sortSelectedIndex - 1;
     
   end
   
   self.moveDownButton.Click = function(sender, args)
      if(self.sortSelectedIndex == self.sortMaxItem) then
         --Turbine.Shell.WriteLine("At the bottom");
         return;
      end
         
      self:SwapShortcuts(self.sortSelectedIndex, self.sortSelectedIndex + 1);      
      
      self.mainWindow:SetShortcuts();
		self.mainWindow:UpdateSettings();
		
      self.sortSelectedIndex = self.sortSelectedIndex + 1;   
   end
    
end

function OptionsWindow:SwapShortcuts(first, second)
   if(self.loading == false) then      
      temp = settings.order[first];
      settings.order[first] = settings.order[second];
      settings.order[second] = temp;
      
      tempItem = self.sortListBox:GetItem(first);
      self.sortListBox:RemoveItemAt(first);
      self.sortListBox:InsertItem(second,tempItem);
    
      
   end
end